pub fn card_for_ref_with_fallback(
cx: &mut Cx,
subject: Ref,
fallback: Option<Value>,
default_kind: Option<Symbol>,
) -> Result<Value>Expand description
Builds a card for subject with optional fallback table data and a
default_kind used when no kind claim or fallback is present.