Module key

Module key 

Composite table/key string keys used by catalog views and overlays.

Functions

catalog_key
Build a deterministic ASCII catalog key from a namespace and path parts.
split_catalog_key
Split a deterministic catalog key back into decoded path components.