class_is_subclass_of

Function class_is_subclass_of 

pub fn class_is_subclass_of(
    cx: &mut Cx,
    child: &dyn Class,
    expected: ClassRef,
) -> Result<bool>
Walk the parent chain of child to test whether it is a subclass of expected, returning false when either side is not a class object.