pub fn abort(cx: &mut Cx, abort: ControlAbort) -> Result<Ref>Expand description
Abort to a prompt with a value via the active control policy.
pub fn abort(cx: &mut Cx, abort: ControlAbort) -> Result<Ref>Abort to a prompt with a value via the active control policy.