pub fn capture(cx: &mut Cx, capture: ControlCapture) -> Result<Ref>Expand description
Capture the continuation up to a prompt via the active control policy.
pub fn capture(cx: &mut Cx, capture: ControlCapture) -> Result<Ref>Capture the continuation up to a prompt via the active control policy.