pub fn resume(cx: &mut Cx, resume: ControlResume) -> Result<Ref>Expand description
Resume a captured continuation with a value via the active control policy.
pub fn resume(cx: &mut Cx, resume: ControlResume) -> Result<Ref>Resume a captured continuation with a value via the active control policy.