pub fn unsupported_control_diagnostic(
policy: &'static str,
operation: Symbol,
) -> DiagnosticExpand description
Build the diagnostic reported when policy cannot perform operation.
pub fn unsupported_control_diagnostic(
policy: &'static str,
operation: Symbol,
) -> DiagnosticBuild the diagnostic reported when policy cannot perform operation.