pub struct ControlCapture {
pub prompt: Ref,
pub continuation: Ref,
pub value: Ref,
pub result_shape: Ref,
pub multishot: bool,
}Expand description
Record describing a capture of the continuation up to a prompt.
Fields
prompt: RefReference identifying the prompt boundary captured up to.
continuation: RefReference to the captured continuation.
value: RefValue delivered to the captured continuation.
result_shape: RefShape the resumed result must satisfy.
multishot: boolWhether the continuation may be resumed more than once.
Implementations