pub struct LibBootDependency {
pub lib_id: LibId,
pub symbol: Symbol,
}Expand description
A loaded dependency edge recorded in a boot receipt.
Fields
lib_id: LibIdStable id of the loaded dependency in the recorded boot session.
symbol: SymbolManifest symbol of the loaded dependency.