pub type NativeAbiCall = unsafe extern "C" fn(instance: *mut c_void, function: *const c_char, args: NativeAbiBorrowedBytes) -> NativeAbiCallResponse;Expand description
Entry that invokes a named guest function with borrowed argument bytes.
pub type NativeAbiCall = unsafe extern "C" fn(instance: *mut c_void, function: *const c_char, args: NativeAbiBorrowedBytes) -> NativeAbiCallResponse;Entry that invokes a named guest function with borrowed argument bytes.