pub type NativeAbiDestroyBytes = unsafe extern "C" fn(bytes: NativeAbiOwnedBytes);Expand description
Entry that frees bytes the guest previously handed back to the host.
pub type NativeAbiDestroyBytes = unsafe extern "C" fn(bytes: NativeAbiOwnedBytes);Entry that frees bytes the guest previously handed back to the host.