pub type NativeAbiDestroyError = unsafe extern "C" fn(error: *mut NativeAbiError);Expand description
Entry that frees an error the guest previously handed back to the host.
pub type NativeAbiDestroyError = unsafe extern "C" fn(error: *mut NativeAbiError);Entry that frees an error the guest previously handed back to the host.