ClaimSink

Trait ClaimSink 

pub trait ClaimSink {
    // Required method
    fn claim(&mut self, claim: Claim) -> Result<()>;
}
Sink that collects claims emitted while reflecting over an object.

Required Methods

fn claim(&mut self, claim: Claim) -> Result<()>

Accept one emitted claim.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ClaimSink for Vec<Claim>

Source

fn claim(&mut self, claim: Claim) -> Result<()>

Collect the claim by pushing it onto the vector.

Implementors