value_from_datum

Function value_from_datum 

pub fn value_from_datum(cx: &mut Cx, datum: Datum) -> Result<Value>
Builds a runtime Value from interned content datum, mapping symbol-keyed maps to tables and other maps to map expressions.