value_from_ref

Function value_from_ref 

pub fn value_from_ref(cx: &mut Cx, reference: &Ref) -> Result<Value>
Resolves reference to a runtime Value, erroring when it cannot be turned into one (a missing or coordinate reference, or an unresolved symbol).