pub fn sequence_item_value(cx: &mut Cx, item: SequenceItem) -> Result<Value>Expand description
Projects a sequence item to a value, wrapping it in a payload/ticks table when ticks are present.
pub fn sequence_item_value(cx: &mut Cx, item: SequenceItem) -> Result<Value>Projects a sequence item to a value, wrapping it in a payload/ticks table when ticks are present.