Composite table/key string keys used by catalog views and overlays.
Functions
- catalog_
key - Build a deterministic ASCII catalog key from a namespace and path parts.
- split_
catalog_ key - Split a deterministic catalog key back into decoded path components.