pub struct BTreeFactStore { /* private fields */ }Implementations
Sourceimpl BTreeFactStore
impl BTreeFactStore
Sourcepub fn get(&self, id: &ContentId) -> Option<&Claim>
pub fn get(&self, id: &ContentId) -> Option<&Claim>
Returns the stored claim with content id id, if present.
Sourcepub fn remove(&mut self, id: &ContentId) -> Option<Claim>
pub fn remove(&mut self, id: &ContentId) -> Option<Claim>
Removes the claim with content id id, updating every query index.
Sourcepub fn insert_boot_claims(&mut self, data: &mut BTreeDatumStore)
pub fn insert_boot_claims(&mut self, data: &mut BTreeDatumStore)
Seeds the fixed core boot claims (the kernel class kind facts) into
this store and their datums into data.