The Stream contract: an object that yields values until closed.
This is protocol the libraries implement; the kernel defines the stream trait, not the concrete transport behind any stream.
Traits
- Stream
- A runtime object that yields values one at a time until it is closed.